﻿<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0"
		        xmlns="http://www.w3.org/1999/xhtml"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:msa="http://www.publictalksoftware.co.uk/msa">
	<!-- Output specification -->
	<xsl:output method="html" indent="yes" version="4.01"
	  doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"
	  doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN"/>

	<!-- Parameters -->
	<xsl:param name="CSSFile1"></xsl:param>

	<!-- Variables -->
	<xsl:variable name="PubDB" select="document('MSA_PublisherDatabase.XML')"/>

	<!-- Labels -->
	<xsl:variable name="labelReportHeading">Availability Status Report</xsl:variable>
	<xsl:variable name="labelColumnDate">Date</xsl:variable>
	<xsl:variable name="labelColumnAssignment">Assignment</xsl:variable>
	<xsl:variable name="labelColumnPublisher">Publisher</xsl:variable>
	<xsl:variable name="labelColumnAvailability">Availability</xsl:variable>
	<xsl:variable name="labelChairman">Chairman</xsl:variable>
	<xsl:variable name="labelHost">Host</xsl:variable>
	<xsl:variable name="labelCohost">Cohost</xsl:variable>
	<xsl:variable name="labelTreasures">Treasures</xsl:variable>
	<xsl:variable name="labelBibleReader">Bible Reader</xsl:variable>
	<xsl:variable name="labelDiscussion">Discussion with Video</xsl:variable>
	<xsl:variable name="labelStudent">Student</xsl:variable>
	<xsl:variable name="labelAssistant">Assistant</xsl:variable>
	<xsl:variable name="labelLiving">Living</xsl:variable>
	<xsl:variable name="labelConductorCBS">CBS Conductor</xsl:variable>
	<xsl:variable name="labelReaderCBS">CBS Reader</xsl:variable>
	<xsl:variable name="labelAvailableForDate">Still available for this date</xsl:variable>
	<xsl:variable name="labelNotAvailableForDate">Not available for this date</xsl:variable>
	<xsl:variable name="labelNotAvailable">Not available for any Midweek items</xsl:variable>

	<xsl:template match="/">
		<html xmlns="http://www.w3.org/1999/xhtml">
			<head>
				<title>
					<xsl:value-of select="$labelReportHeading"/>
				</title>
				<xsl:choose>
					<xsl:when test="$CSSFile1 !=''">
						<style type="text/css">
							<xsl:value-of select="$CSSFile1"/>
						</style>
					</xsl:when>
					<xsl:otherwise>
						<link rel="stylesheet" type="text/css" href="Custom--S-140--Availability.css"/>
					</xsl:otherwise>
				</xsl:choose>
			</head>
			<body>
				<table class="availability">
					<thead>
						<tr>
							<td class="header">
								<xsl:value-of select="$labelColumnDate"/>
							</td>
							<td class="header">
								<xsl:value-of select="$labelColumnAssignment"/>
							</td>
							<td class="header">
								<xsl:value-of select="$labelColumnPublisher"/>
							</td>
							<td class="header">
								<xsl:value-of select="$labelColumnAvailability"/>
							</td>
						</tr>
					</thead>
					<tbody>
						<xsl:for-each select="MeetingWorkBook/Meeting">
							<!-- Build the lookup date string YYYY-MM-DD -->
							<xsl:variable name="strDate">
								<xsl:value-of select="MeetingDate/@Year"/>
								<xsl:value-of select="format-number(MeetingDate/@Month, '-00')"/>
								<xsl:value-of select="format-number(MeetingDate/@Day, '-00')"/>
							</xsl:variable>
							<!-- Now we can pass this date as a parameter -->
							<xsl:apply-templates select="Chairman">
								<xsl:with-param name="strDateOfMeeting" select="$strDate"/>
								<xsl:with-param name="strAssignmentType">
									<xsl:value-of select="$labelChairman"/>
								</xsl:with-param>
							</xsl:apply-templates>
							<xsl:apply-templates select="VideoConferenceHost">
								<xsl:with-param name="strDateOfMeeting" select="$strDate"/>
								<xsl:with-param name="strAssignmentType">
									<xsl:value-of select="$labelHost"/>
								</xsl:with-param>
							</xsl:apply-templates>
							<xsl:apply-templates select="VideoConferenceCohost">
								<xsl:with-param name="strDateOfMeeting" select="$strDate"/>
								<xsl:with-param name="strAssignmentType">
									<xsl:value-of select="$labelCohost"/>
								</xsl:with-param>
							</xsl:apply-templates>
							<xsl:apply-templates select="TFGW/TFGWItem/Name">
								<xsl:with-param name="strDateOfMeeting" select="$strDate"/>
								<xsl:with-param name="strAssignmentType">
									<xsl:value-of select="$labelTreasures"/>
								</xsl:with-param>
							</xsl:apply-templates>
							<xsl:apply-templates select="TFGW/BibleReadingItem/Readers/Reader">
								<xsl:with-param name="strDateOfMeeting" select="$strDate"/>
								<xsl:with-param name="strAssignmentType">
									<xsl:value-of select="$labelBibleReader"/>
								</xsl:with-param>
							</xsl:apply-templates>
							<xsl:apply-templates select="AYFM/Teaching/Names/Name">
								<xsl:with-param name="strDateOfMeeting" select="$strDate"/>
								<xsl:with-param name="strAssignmentType">
									<xsl:value-of select="$labelDiscussion"/>
								</xsl:with-param>
							</xsl:apply-templates>
							<xsl:apply-templates select="AYFM/StudentItem/Students/Student">
								<xsl:with-param name="strDateOfMeeting" select="$strDate"/>
								<xsl:with-param name="strAssignmentType">
									<xsl:value-of select="$labelStudent"/>
								</xsl:with-param>
							</xsl:apply-templates>
							<xsl:apply-templates select="AYFM/StudentItem/Students/Assistant">
								<xsl:with-param name="strDateOfMeeting" select="$strDate"/>
								<xsl:with-param name="strAssignmentType">
									<xsl:value-of select="$labelAssistant"/>
								</xsl:with-param>
							</xsl:apply-templates>
							<xsl:apply-templates select="LAC/LACItem/Name">
								<xsl:with-param name="strDateOfMeeting" select="$strDate"/>
								<xsl:with-param name="strAssignmentType">
									<xsl:value-of select="$labelLiving"/>
								</xsl:with-param>
							</xsl:apply-templates>
							<xsl:apply-templates select="LAC/CongregationBibleStudy/Conductor">
								<xsl:with-param name="strDateOfMeeting" select="$strDate"/>
								<xsl:with-param name="strAssignmentType">
									<xsl:value-of select="$labelConductorCBS"/>
								</xsl:with-param>
							</xsl:apply-templates>
							<xsl:apply-templates select="LAC/CongregationBibleStudy/Reader">
								<xsl:with-param name="strDateOfMeeting" select="$strDate"/>
								<xsl:with-param name="strAssignmentType">
									<xsl:value-of select="$labelReaderCBS"/>
								</xsl:with-param>
							</xsl:apply-templates>
						</xsl:for-each>
					</tbody>
				</table>
			</body>
		</html>
	</xsl:template>
	<xsl:template match="Chairman | VideoConferenceHost | VideoConferenceCohost | Name | Student | Assistant | Conductor | Reader">
		<xsl:param name="strDateOfMeeting"/>
		<xsl:param name="strAssignmentType"/>
		<xsl:variable name="strName" select="string(.)"/>
		<xsl:if test="$strName!=''">
			<tr>
				<td>
					<xsl:value-of select="ancestor::Meeting/MeetingDate/@DayShort"/>
					<xsl:text> </xsl:text>
					<xsl:value-of select="format-number(ancestor::Meeting/MeetingDate/@Day, '00')"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="format-number(ancestor::Meeting/MeetingDate/@Month, '00')"/>
					<xsl:text>-</xsl:text>
					<xsl:value-of select="ancestor::Meeting/MeetingDate/@Year"/>
				</td>
				<td>
					<xsl:value-of select="$strAssignmentType"/>
				</td>
				<td>
					<xsl:value-of select="."/>
				</td>
				<!-- Is this person still available for Midweek items? -->
				<xsl:choose>
					<xsl:when test="$PubDB/msa:PublisherDatabase/msa:Publishers/msa:Publisher[ msa:Name=normalize-space($strName)]/msa:Availability/@Midweek='true'">
						<!-- Now we need to see if they are still available for this actual date -->
						<xsl:choose>
							<xsl:when test=" count( $PubDB/msa:PublisherDatabase/msa:Publishers/msa:Publisher[msa:Name=normalize-space($strName)]/ msa:Availability/msa:DatesNotAvailable[msa:Date=normalize-space($strDateOfMeeting)])=0">
								<td>
									<xsl:value-of select="$labelAvailableForDate"/>
								</td>
							</xsl:when>
							<xsl:otherwise>
								<td class="notavailable">
									<em>
										<xsl:value-of select="$labelNotAvailableForDate"/>
									</em>
								</td>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<td class="notavailable permanent">
							<em>
								<xsl:value-of select="$labelNotAvailable"/>
							</em>
						</td>
					</xsl:otherwise>
				</xsl:choose>
			</tr>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>